jppy - Python Binding for the JPP Framework used in KM3NeT
==========================================================

Installation
------------

    pip install cython numpy
    pip install /path/to/cloned/repository
